From f6a5bfe48ac9cddf5baa2de1e7ae9ca119251079 Mon Sep 17 00:00:00 2001
From: Eric Blake <eblake@redhat.com>
Date: Thu, 1 Jun 2017 16:58:17 +0200
Subject: [PATCH 01/17] shutdown: Simplify shutdown_signal

RH-Author: Eric Blake <eblake@redhat.com>
Message-id: <20170601165821.26810-2-eblake@redhat.com>
Patchwork-id: 75464
O-Subject: [RHEL-7.4 qemu-kvm-rhev PATCH v2 1/5] shutdown: Simplify shutdown_signal
Bugzilla: 1418927
RH-Acked-by: John Snow <jsnow@redhat.com>
RH-Acked-by: Markus Armbruster <armbru@redhat.com>
RH-Acked-by: Thomas Huth <thuth@redhat.com>

There is no signal 0 (kill(pid, 0) has special semantics to probe whether
a process is alive), rather than actually sending a signal 0).  So we
can use the simpler 0, instead of -1, for our sentinel of whether a
shutdown request due to a signal has happened.

Suggested-by: Markus Armbruster <armbru@redhat.com>
Signed-off-by: Eric Blake <eblake@redhat.com>
Reviewed-by: Markus Armbruster <armbru@redhat.com>
Reviewed-by: Alistair Francis <alistair.francis@xilinx.com>
Message-Id: <20170515214114.15442-2-eblake@redhat.com>
Signed-off-by: Markus Armbruster <armbru@redhat.com>
(cherry picked from commit 7af88279e4972dd6bf735b620876d54b7a355c4d)
Signed-off-by: Miroslav Rezanina <mrezanin@redhat.com>
---
 vl.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/vl.c b/vl.c
index 183f070..f5dea2c 100644
--- a/vl.c
+++ b/vl.c
@@ -1597,7 +1597,7 @@ void vm_state_notify(int running, RunState state)
 }
 
 static int reset_requested;
-static int shutdown_requested, shutdown_signal = -1;
+static int shutdown_requested, shutdown_signal;
 static pid_t shutdown_pid;
 static int powerdown_requested;
 static int debug_requested;
@@ -1628,7 +1628,7 @@ static int qemu_shutdown_requested(void)
 
 static void qemu_kill_report(void)
 {
-    if (!qtest_driver() && shutdown_signal != -1) {
+    if (!qtest_driver() && shutdown_signal) {
         if (shutdown_pid == 0) {
             /* This happens for eg ^C at the terminal, so it's worth
              * avoiding printing an odd message in that case.
@@ -1642,7 +1642,7 @@ static void qemu_kill_report(void)
                          shutdown_cmd ? shutdown_cmd : "<unknown process>");
             g_free(shutdown_cmd);
         }
-        shutdown_signal = -1;
+        shutdown_signal = 0;
     }
 }
 
-- 
1.8.3.1

